@@ -1,3 +1,9 @@
+"""Image profiling backends and helpers.
+
+This package exposes image profiler implementations used by filoma's
+image analysis utilities.
+"""
+
 from .base import BaseImageProfiler as BaseImageProfiler
 from .npy_profiler import NpyProfiler as NpyProfiler
 from .png_profiler import PngProfiler as PngProfiler
