@@ -15,6 +15,8 @@ use std::time::Instant;
 pub struct AnalysisConfig {
     pub max_depth: Option<u32>,
     pub follow_links: bool,
+    pub search_hidden: bool,
+    pub no_ignore: bool,
     pub parallel: bool,
     pub parallel_threshold: usize,
     pub log_progress: bool,
@@ -26,6 +28,8 @@ impl Default for AnalysisConfig {
         Self {
             max_depth: None,
             follow_links: false,
+            search_hidden: true,
+            no_ignore: true,
             parallel: true,
             parallel_threshold: 1000, // Use parallel processing for directories with >1000 entries
             log_progress: false,
@@ -75,7 +79,7 @@ impl ParallelDirectoryStats {
     }
 
     fn add_folder(&self, name: String, is_empty: bool, path: String, depth: u32) {
-        self.total_folders.fetch_add(1, Ordering::Relaxed);
+    self.total_folders.fetch_add(1, Ordering::Relaxed);
         
         // Update max depth atomically
         self.max_depth.fetch_max(depth, Ordering::Relaxed);
@@ -152,10 +156,11 @@ impl DirectoryStats {
         self.elapsed_seconds = elapsed_seconds;
     }
 
-    fn to_py_dict(&self, py: Python, root_path: &str) -> PyResult<PyObject> {
+    fn to_py_dict(&self, py: Python, path_root: &str) -> PyResult<PyObject> {
         let dict = PyDict::new(py);
         
-        dict.set_item("root_path", root_path)?;
+        // Return the probed path under the key 'path' for Python consistency
+    dict.set_item("path", path_root)?;
         
         // Summary
         let summary = PyDict::new(py);
@@ -260,17 +265,41 @@ mod analysis {
 
 use analysis::*;
 
+/// Convert an entry path to an absolute path string relative to the probe root.
+/// If `follow_links` is true we attempt to canonicalize the entry path (resolving
+/// symlinks). If canonicalize fails or follow_links is false, we compose an absolute
+/// path by joining the canonicalized probe root with the entry's path relative to the root.
+pub fn make_absolute_path_str(entry_path: &std::path::Path, root: &std::path::Path, root_abs: &std::path::Path, follow_links: bool) -> String {
+    if follow_links {
+        if let Ok(canon) = entry_path.canonicalize() {
+            return canon.to_string_lossy().to_string();
+        }
+        // Fall through to path composition if canonicalize fails
+    }
+
+    match entry_path.strip_prefix(root) {
+        Ok(rel) => root_abs.join(rel).to_string_lossy().to_string(),
+        Err(_) => entry_path.to_string_lossy().to_string(),
+    }
+}
+
+// Async scanner module
+mod async_scan;
+use async_scan::probe_directory_rust_async;
+
 /// Sequential directory analysis engine
 mod sequential {
     use super::*;
 
-    pub fn analyze_directory_sequential(
-        root_path: &Path,
+    pub fn probe_directory_sequential(
+        path_root: &Path,
         config: &AnalysisConfig,
     ) -> Result<DirectoryStats, String> {
         let start_time = Instant::now();
         let mut stats = DirectoryStats::new();
-        let mut walker = WalkDir::new(root_path).follow_links(config.follow_links);
+    // Pre-compute absolute root used to construct absolute paths for entries
+    let root_abs = path_root.canonicalize().unwrap_or_else(|_| path_root.to_path_buf());
+    let mut walker = WalkDir::new(path_root).follow_links(config.follow_links);
 
         // Set max_depth on the walker if specified
         if let Some(max_d) = config.max_depth {
@@ -306,7 +335,7 @@ mod sequential {
 
                 // Check if empty
                 if is_empty_directory(&entry) {
-                    stats.empty_folders.push(entry.path().to_string_lossy().to_string());
+                    stats.empty_folders.push(make_absolute_path_str(entry.path(), path_root, &root_abs, config.follow_links));
                 }
 
                 // Count folder name
@@ -316,7 +345,7 @@ mod sequential {
 
                 // Initialize folder file count
                 stats.files_per_folder.entry(
-                    entry.path().to_string_lossy().to_string()
+                    make_absolute_path_str(entry.path(), path_root, &root_abs, config.follow_links)
                 ).or_insert(0);
 
             } else if entry.file_type().is_file() {
@@ -336,13 +365,13 @@ mod sequential {
                 // Count file in its parent directory
                 if let Some(parent) = entry.path().parent() {
                     *stats.files_per_folder.entry(
-                        parent.to_string_lossy().to_string()
+                        make_absolute_path_str(parent, path_root, &root_abs, config.follow_links)
                     ).or_insert(0) += 1;
                 }
             }
         }
 
-        let elapsed = start_time.elapsed();
+    let elapsed = start_time.elapsed();
         stats.set_timing(elapsed.as_secs_f64());
 
         Ok(stats)
@@ -353,65 +382,71 @@ mod sequential {
 mod parallel {
     use super::*;
 
-    pub fn analyze_directory_parallel(
-        root_path: &Path,
+    pub fn probe_directory_parallel(
+        path_root: &Path,
         config: &AnalysisConfig,
     ) -> Result<DirectoryStats, String> {
         let start_time = Instant::now();
         let stats = Arc::new(ParallelDirectoryStats::new());
         
-        // First, analyze the root directory itself
-        analyze_root_directory(root_path, &stats, config)?;
+    // First, compute absolute root used for path composition
+    let root_abs = path_root.canonicalize().unwrap_or_else(|_| path_root.to_path_buf());
+    // Probe the root directory itself
+    probe_root_directory(path_root, &stats, config)?;
         
         // Get immediate subdirectories for parallel processing
-        let subdirs = get_subdirectories(root_path, config);
+    let subdirs = get_subdirectories(path_root, config);
         
         // Decide whether to use parallel processing
-        let should_parallelize = subdirs.len() > 4 && 
+    let should_parallelize = subdirs.len() > 4 && 
             estimate_total_size(&subdirs) > config.parallel_threshold;
         
         if should_parallelize && subdirs.len() > 1 {
             // Process subdirectories in parallel
+            let root_clone = path_root.to_path_buf();
+            let root_abs_clone = root_abs.clone();
             subdirs.par_iter().for_each(|subdir| {
-                let _ = analyze_subdirectory_recursive(subdir, &stats, config, 1);
+                let _ = probe_subdirectory_recursive(subdir, &stats, config, 1, &root_clone, &root_abs_clone);
             });
         } else {
             // Fall back to sequential processing for small directories
             for subdir in subdirs {
-                let _ = analyze_subdirectory_recursive(&subdir, &stats, config, 1);
+                let _ = probe_subdirectory_recursive(&subdir, &stats, config, 1, path_root, &root_abs);
             }
         }
         
-        let elapsed = start_time.elapsed();
-        let mut result = stats.to_directory_stats();
+    let elapsed = start_time.elapsed();
+    let mut result = stats.to_directory_stats();
         result.set_timing(elapsed.as_secs_f64());
         
         Ok(result)
     }
 
-    fn analyze_root_directory(
-        root_path: &Path,
+    fn probe_root_directory(
+        path_root: &Path,
         stats: &Arc<ParallelDirectoryStats>,
         _config: &AnalysisConfig,
     ) -> Result<(), String> {
         // Count the root directory itself
-        if let Some(name) = root_path.file_name().and_then(|n| n.to_str()) {
-            let is_empty = estimate_directory_size(root_path, 1) == 0;
+        if let Some(name) = path_root.file_name().and_then(|n| n.to_str()) {
+            let is_empty = estimate_directory_size(path_root, 1) == 0;
             stats.add_folder(
                 name.to_string(),
                 is_empty,
-                root_path.to_string_lossy().to_string(),
+                path_root.to_string_lossy().to_string(),
                 0
             );
         }
         Ok(())
     }
 
-    fn analyze_subdirectory_recursive(
+    fn probe_subdirectory_recursive(
         dir_path: &Path,
         stats: &Arc<ParallelDirectoryStats>,
         config: &AnalysisConfig,
         current_depth: u32,
+        root: &Path,
+        root_abs: &Path,
     ) -> Result<(), String> {
         // Check depth limit
         if let Some(max_depth) = config.max_depth {
@@ -430,7 +465,7 @@ mod parallel {
             walker = walker.max_depth(remaining_depth as usize + 1);
         }
 
-        for entry in walker {
+    for entry in walker {
             let entry = match entry {
                 Ok(entry) => entry,
                 Err(_) => continue,
@@ -439,6 +474,15 @@ mod parallel {
             let relative_depth = entry.depth() as u32;
             let absolute_depth = current_depth + relative_depth;
 
+            // Skip hidden entries unless search_hidden is enabled
+            if !config.search_hidden {
+                if let Some(name) = entry.file_name().to_str() {
+                    if name.starts_with('.') {
+                        continue;
+                    }
+                }
+            }
+
             if entry.file_type().is_dir() {
                 let is_empty = is_empty_directory(&entry);
                 
@@ -446,7 +490,7 @@ mod parallel {
                     stats.add_folder(
                         name.to_string(),
                         is_empty,
-                        entry.path().to_string_lossy().to_string(),
+                        make_absolute_path_str(entry.path(), root, root_abs, config.follow_links),
                         absolute_depth,
                     );
                 }
@@ -455,8 +499,17 @@ mod parallel {
                 let size = if config.fast_path_only { 0 } else {
                     entry.metadata().map(|m| m.len()).unwrap_or(0)
                 };
+                // Skip hidden files unless requested
+                if !config.search_hidden {
+                    if let Some(fname) = entry.file_name().to_str() {
+                        if fname.starts_with('.') {
+                            continue;
+                        }
+                    }
+                }
+
                 let parent_path = entry.path().parent()
-                    .map(|p| p.to_string_lossy().to_string())
+                    .map(|p| make_absolute_path_str(p, root, root_abs, config.follow_links))
                     .unwrap_or_default();
                 stats.add_file(size, ext, parent_path, config.fast_path_only);
             }
@@ -474,45 +527,55 @@ mod parallel {
 
 /// Python interface functions
 #[pyfunction]
-fn analyze_directory_rust(root_path: &str, max_depth: Option<u32>, fast_path_only: Option<bool>) -> PyResult<PyObject> {
-    analyze_directory_rust_with_config(root_path, max_depth, None, fast_path_only)
+#[pyo3(signature = (path_root, max_depth=None, fast_path_only=None, follow_links=None, search_hidden=None, no_ignore=None))]
+fn probe_directory_rust(path_root: &str, max_depth: Option<u32>, fast_path_only: Option<bool>, follow_links: Option<bool>, search_hidden: Option<bool>, no_ignore: Option<bool>) -> PyResult<PyObject> {
+    probe_directory_rust_with_config(path_root, max_depth, None, fast_path_only, follow_links, search_hidden, no_ignore)
 }
 
 #[pyfunction]
-fn analyze_directory_rust_parallel(
-    root_path: &str, 
-    max_depth: Option<u32>,
-    parallel_threshold: Option<usize>,
-    fast_path_only: Option<bool>
-) -> PyResult<PyObject> {
-    analyze_directory_rust_with_config(root_path, max_depth, parallel_threshold, fast_path_only)
-}
-
-fn analyze_directory_rust_with_config(
-    root_path: &str,
+#[pyo3(signature = (path_root, max_depth=None, parallel_threshold=None, fast_path_only=None, follow_links=None, search_hidden=None, no_ignore=None))]
+fn probe_directory_rust_parallel(
+    path_root: &str, 
     max_depth: Option<u32>,
     parallel_threshold: Option<usize>,
     fast_path_only: Option<bool>,
+    follow_links: Option<bool>,
+    search_hidden: Option<bool>,
+    no_ignore: Option<bool>,
 ) -> PyResult<PyObject> {
-    let root = Path::new(root_path);
+    probe_directory_rust_with_config(path_root, max_depth, parallel_threshold, fast_path_only, follow_links, search_hidden, no_ignore)
+}
+
+fn probe_directory_rust_with_config(
+    path_root: &str,
+    max_depth: Option<u32>,
+    parallel_threshold: Option<usize>,
+    fast_path_only: Option<bool>,
+    follow_links: Option<bool>,
+    search_hidden: Option<bool>,
+    no_ignore: Option<bool>,
+) -> PyResult<PyObject> {
+    let root = Path::new(path_root);
     
     // Validate input
     if !root.exists() {
         return Err(pyo3::exceptions::PyValueError::new_err(
-            format!("Path does not exist: {}", root_path)
+            format!("Path does not exist: {}", path_root)
         ));
     }
     
     if !root.is_dir() {
         return Err(pyo3::exceptions::PyValueError::new_err(
-            format!("Path is not a directory: {}", root_path)
+            format!("Path is not a directory: {}", path_root)
         ));
     }
 
     // Configure analysis
     let config = AnalysisConfig {
         max_depth,
-        follow_links: false,
+        follow_links: follow_links.unwrap_or(true),
+        search_hidden: search_hidden.unwrap_or(true),
+        no_ignore: no_ignore.unwrap_or(true),
         parallel: parallel_threshold.is_some(),
         parallel_threshold: parallel_threshold.unwrap_or(1000),
         log_progress: false,
@@ -520,15 +583,17 @@ fn analyze_directory_rust_with_config(
     };
 
     // Choose analysis method based on configuration and directory size
+    // Use the root_abs as the canonical absolute probe root for Python consumers
+    let root_abs = root.canonicalize().unwrap_or_else(|_| root.to_path_buf());
     let stats = if should_use_parallel_analysis(root, &config) {
-        parallel::analyze_directory_parallel(root, &config)
+        parallel::probe_directory_parallel(root, &config)
     } else {
-        sequential::analyze_directory_sequential(root, &config)
+        sequential::probe_directory_sequential(root, &config)
     };
 
     let stats = stats.map_err(|e| pyo3::exceptions::PyRuntimeError::new_err(e))?;
     
-    Python::with_gil(|py| stats.to_py_dict(py, root_path))
+    Python::with_gil(|py| stats.to_py_dict(py, root_abs.to_string_lossy().as_ref()))
 }
 
 /// Intelligent decision making for when to use parallel processing
@@ -556,7 +621,8 @@ fn should_use_parallel_analysis(root: &Path, config: &AnalysisConfig) -> bool {
 
 #[pymodule]
 fn filoma_core(m: &Bound<'_, PyModule>) -> PyResult<()> {
-    m.add_function(wrap_pyfunction!(analyze_directory_rust, m)?)?;
-    m.add_function(wrap_pyfunction!(analyze_directory_rust_parallel, m)?)?;
+    m.add_function(wrap_pyfunction!(probe_directory_rust, m)?)?;
+    m.add_function(wrap_pyfunction!(probe_directory_rust_parallel, m)?)?;
+    m.add_function(wrap_pyfunction!(probe_directory_rust_async, m)?)?;
     Ok(())
 }
