@@ -1,6 +1,5 @@
 #!/usr/bin/env python3
-"""
-Test script to see how DataFrame works with Rust acceleration.
+"""Test script to see how DataFrame works with Rust acceleration.
 """
 
 import sys
@@ -14,12 +13,11 @@ from filoma.directories.directory_profiler import DirectoryProfiler
 
 def test_rust_with_dataframe():
     """Test DataFrame functionality with Rust enabled."""
-
     # Test with Rust + DataFrame
-    profiler_rust = DirectoryProfiler(
-        use_rust=True,
-        build_dataframe=True
-    )
+    from filoma.directories import DirectoryProfilerConfig
+
+    cfg = DirectoryProfilerConfig(use_rust=True, build_dataframe=True)
+    profiler_rust = DirectoryProfiler(cfg)
 
     print(f"Implementation info: {profiler_rust.get_implementation_info()}")
     print(f"Using Rust: {profiler_rust.is_rust_available()}")
@@ -27,7 +25,7 @@ def test_rust_with_dataframe():
 
     # Analyze current directory
     current_dir = str(Path(__file__).parent.parent.parent)  # Go to repo root
-    analysis = profiler_rust.analyze(current_dir, max_depth=1)
+    analysis = profiler_rust.probe(current_dir, max_depth=1)
 
     # Check if DataFrame was created
     df = profiler_rust.get_dataframe(analysis)
@@ -38,5 +36,6 @@ def test_rust_with_dataframe():
 
     print(f"Analysis keys: {list(analysis.keys())}")
 
+
 if __name__ == "__main__":
     test_rust_with_dataframe()
