@@ -3,10 +3,12 @@ import numpy as np
 from filoma.images.image_profiler import ImageProfiler
 
 
-def test_analyze_basic_stats():
+def test_probe_basic_stats():
     arr = np.array([[1, 2, 3], [4, 5, 6]])
     profiler = ImageProfiler()
-    report = profiler.analyze(arr)
+    profiler = ImageProfiler()
+    report_obj = profiler.probe(arr)
+    report = report_obj.to_dict()
     assert report["shape"] == (2, 3)
     assert report["dtype"] == "int64"
     assert report["min"] == 1
@@ -16,17 +18,23 @@ def test_analyze_basic_stats():
     assert report["infs"] == 0
     assert report["unique"] == 6
 
-def test_analyze_with_nans_and_infs():
+
+def test_probe_with_nans_and_infs():
     arr = np.array([[np.nan, np.inf, 1], [2, 2, 3]])
     profiler = ImageProfiler()
-    report = profiler.analyze(arr)
+    profiler = ImageProfiler()
+    report_obj = profiler.probe(arr)
+    report = report_obj.to_dict()
     assert report["nans"] == 1
     assert report["infs"] == 1
     assert report["unique"] >= 3
 
-def test_analyze_empty_array():
+
+def test_probe_empty_array():
     arr = np.array([])
     profiler = ImageProfiler()
-    report = profiler.analyze(arr)
+    profiler = ImageProfiler()
+    report_obj = profiler.probe(arr)
+    report = report_obj.to_dict()
     assert report["shape"] == (0,)
     assert report["unique"] == 0
